@@ -1,7 +1,8 @@
-use axum::body;
-use axum::extract::rejection::{BytesRejection, HeadersAlreadyExtracted};
-use axum::response::Response;
+use axum_core::body;
+use axum_core::extract::rejection::{BytesRejection, HeadersAlreadyExtracted};
+use axum_core::response::Response;
 use http::StatusCode;
+use http_body::Full;
 use thiserror::Error;
 
 use crate::IntoResponse;
@@ -22,12 +23,12 @@ impl IntoResponse for XmlRejection {
     fn into_response(self) -> crate::Response {
         match self {
             e @ XmlRejection::InvalidXMLBody(_) => {
-                let mut res = Response::new(body::boxed(body::Full::from(format!("{}", e))));
+                let mut res = Response::new(body::boxed(Full::from(format!("{}", e))));
                 *res.status_mut() = StatusCode::UNPROCESSABLE_ENTITY;
                 res
             }
             e @ XmlRejection::MissingXMLContentType => {
-                let mut res = Response::new(body::boxed(body::Full::from(format!("{}", e))));
+                let mut res = Response::new(body::boxed(Full::from(format!("{}", e))));
                 *res.status_mut() = StatusCode::UNSUPPORTED_MEDIA_TYPE;
                 res
             }
